#!/bin/bash

# Get the current kernel version
KERNEL_VERSION=$(uname -r)
WORKING_DIR=$(pwd)

echo "System kernel version: ${KERNEL_VERSION}" 

# Check again the file
MODULE_KO_PATH=$(find "$WORKING_DIR" -name "oegevmodule-*-${KERNEL_VERSION}.ko" | head -n 1)
if [ -z "$MODULE_KO_PATH" ]; then
    echo "No kernel module (oegevmodule-*-${KERNEL_VERSION}.ko)"
    exit 1
fi

# Install the kernel module
echo "Installing kernel module: ${MODULE_KO_PATH}..."

# save the .ko module in the system dir
mkdir -p /lib/modules/$(uname -r)/extra
cp -T ${MODULE_KO_PATH} /lib/modules/$(uname -r)/extra/oegevmodule.ko
if [ $? -ne 0 ]; then
    echo "Failed to save .ko file in the system path. Do you have permission?"
    exit 1
fi
echo "Saved ${MODULE_KO_PATH} file in /lib/modules/$(uname -r)/extra/oegevmodule.ko"


# .conf file to run when loading the module
echo "Configuring /etc/modprobe.d/oegevmodule.conf..."
echo -e "\ninstall oegevmodule /sbin/modprobe --ignore-install oegevmodule; \\" > /etc/modprobe.d/oegevmodule.conf
for i in $(seq 0 9); do
    echo "test -e /dev/oegevmodule$i || mknod -m 666 /dev/oegevmodule$i c 120 $i; \\" >> /etc/modprobe.d/oegevmodule.conf
done
echo "" >> /etc/modprobe.d/oegevmodule.conf

# load module at boot
echo "Configuring /etc/modules-load.d/oegevmodule.conf..."
echo oegevmodule > /etc/modules-load.d/oegevmodule.conf

# reload all modules dependencies
echo "Loading all modules dependencies with depmod..."
depmod -a

# activate module
echo "Loading oegevmodule with modprobe..."
ERROR_MESSAGE=$(modprobe oegevmodule 2>&1)
if [[ ! -z ${ERROR_MESSAGE} ]]; then
    echo "Failed to install the kernel module."
    echo ${ERROR_MESSAGE}
    exit 1
fi

echo "Kernel module installed successfully."

